function [cv,cvstep] = CV(y, X, algo)

[n,p] = size(X);
subset = zeros(n-1,n);

if strcmp(algo,'MPA')   
    mub=20000;
    nu=0.1;
    SEL = zeros(mub,1); %square error loss
    SEL_vec = zeros(mub,n);
    for i = 1:n
        subset(:,i) = datasample(1:n, n-1, 'Replace',false);
        [Matbeta, vec_err_n, vec_df, ITC, vec_combr] = mpa( y(subset(:,i),:), X(subset(:,i),:), mub, nu);
        X_prime = X(setdiff((1:n), subset(:,i)),:);
        y_prime = y(setdiff((1:n), subset(:,i)),:);
        for j = 1:mub
            SEL(j) = (y_prime - X_prime*Matbeta(:,j))^2;
        end %for j
        SEL_vec(:,i) = SEL;
    end % for i
    
    
elseif strcmp(algo,'OMP')   
    maxNumCoef = min(n,p);
    const = maxNumCoef;
    SEL = zeros(const,1); %square error loss
    SEL_vec = zeros(const,n);    
    for i = 1:n
        subset(:,i) = datasample(1:n, n-1, 'Replace',false);
        [Matbeta, vec_err, ITC, vec_combr] = omp( y(subset(:,i),:), X(subset(:,i),:));
        X_prime = X(setdiff((1:n), subset(:,i)),:);
        y_prime = y(setdiff((1:n), subset(:,i)),:);   
        for j = 1:const       
            if Matbeta(:,j) == zeros(p,1)
                break;
            end
            SEL(j) = (y_prime - X_prime*Matbeta(:,j))^2;
        end
    SEL_vec(:,i) = SEL;   
    end % for i
 
    
elseif strcmp(algo,'RMP')
    mub=20000;
    SEL = zeros(mub,1); %square error loss
    SEL_vec = zeros(mub,n);
    for i = 1:n
        subset(:,i) = datasample(1:n, n-1, 'Replace',false);
        [Matbeta, vec_err_n, vec_df, ITC, vec_combr] = rmp( y(subset(:,i),:), X(subset(:,i),:), mub);
        X_prime = X(setdiff((1:n), subset(:,i)),:);
        y_prime = y(setdiff((1:n), subset(:,i)),:);
        for j = 1:mub
            SEL(j) = (y_prime - X_prime*Matbeta(:,j))^2;
        end
        SEL_vec(:,i) = SEL;
    end % for i
elseif strcmp(algo,'FWA')
        flag_warm_start = 0;
        flag_ls         = 1;
        mub             = 20000;
        prec            = 10^(-6);
        Ng              = 20;    
        for i = 1:n
            subset(:,i) = datasample(1:n, n-1, 'Replace',false);    
            [Matbeta, ~, ~, ~, ~] = fwa( y(subset(:,i),:), X(subset(:,i),:), flag_warm_start, flag_ls,  mub, prec, Ng);
            X_prime = X(setdiff((1:n), subset(:,i)),:);
            y_prime = y(setdiff((1:n), subset(:,i)),:);
            for j = 1:Ng
                SEL(j) = (y_prime - X_prime*Matbeta(:,j))^2;
            end
            SEL_vec(:,i) = SEL;
        end % for i
    
elseif strcmp(algo,'CMP')
        flag_warm_start = 1;
        flag_ls         = 1;
        mub             = 20000;
        prec            = 10^(-6);
        Ng              = 20;
        
        for i = 1:n
            subset(:,i) = datasample(1:n, n-1, 'Replace',false);
            [Matbeta, ~, ~, ~, ~] = cmp( y(subset(:,i),:), X(subset(:,i),:), flag_warm_start, flag_ls, mub, prec, Ng);

            X_prime = X(setdiff((1:n), subset(:,i)),:);
            y_prime = y(setdiff((1:n), subset(:,i)),:);
            for j = 1:Ng
                SEL(j) = (y_prime - X_prime*Matbeta(:,j))^2;
            end
            SEL_vec(:,i) = SEL;
        end%for i       
else
        fprintf('Incorrect greedy algorithm');
        return;
end %if        
        
cv = mean(SEL_vec,2);
[~,cvstep] = min(cv);     

end
