function [start0,stop] = exp_data_uk(labels, label_reg, flag_others, n, nstep, algo)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%labels            labels for all regions
%label_region      label region to be predicted
%flag_others       0 = only predictors from the same region
%                  1 = only predictors from the other regions
%                  2 = predictors from all regions
% n                %no. of measurements/year 
% nstep            no. of months after which the model is adapted
% algo             greedy algorithm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load('HPI');          % use HPI
data = HPI;

pos = [3 1 6 9 10];

cc = strcmp(labels,label_reg);
if sum(cc)==0
    fprintf('Incorrect name for the region!\n');
    return;
else
    ffy= find(cc==1);
    if length(ffy)>1
        fprintf('Incorrect name for the region!\n');
        return;
    else
        yy = data(:,pos(ffy));
        ffx = find(cc==0);
        if flag_others==0
            XX = data(:,pos(ffy));
        elseif flag_others==1
            XX = data(:,pos(ffx));
        elseif  flag_others==2
            XX = [data(:,pos(ffy)) data(:,pos(ffx))];
        else
            fprintf('Incorrect value for flag_others!\n');
            return;
        end 
    end
end


N = size(yy,1);     %total no. of measurements
start = n+1;
start0 = start;
stop = N-(n+nstep-1);
%%%%%%%%%%%%
folder_name = strcat('./HPIResults/');
[suc,~,~] = mkdir(folder_name);
if suc==0
    return;
end 

fname = strcat('./HPIResults/', algo,'_',label_reg,'_PredErrors.mat');
if isfile(fname)==0
    if strcmp(algo,'MPA')||strcmp(algo,'RMP')
       ERRORS = Inf*ones(3,23,nstep,stop-start+1);
    elseif strcmp(algo,'OMP')||strcmp(algo,'CMP')||strcmp(algo,'FWA')
       ERRORS = Inf*ones(3,13,nstep,stop-start+1);       
    end
else
    load(fname);
end
    
while start<stop+1  
    
    %Learning
    y = yy(start:start+n-1);
    X = [];
    for c=1:size(XX,2)
        X = [X toeplitz(XX(start-1:start+n-2,c),XX(start-1:-1:start-n,c)')];
    end
    
    if strcmp(algo,'MPA')
        mub = 20000;
        nu=0.1;
        [Matbeta,~, ~, ITC, ~, ~] = mpa( y, X, mub, nu );
    elseif strcmp(algo,'OMP')
        [Matbeta, ~, ITC, ~] = omp(y, X);
    elseif strcmp(algo,'RMP')
        mub = 20000;
        [Matbeta,~, ~, ITC, ~, ~] = rmp( y, X, mub);
    elseif strcmp(algo,'FWA')
        flag_warm_start = 0;
        flag_ls         = 1;
        mub             = 20000;
        prec            = 10^(-6);
        Ng              = 20;
        [Matbeta, ~, ~, ~, ITC] = fwa( y, X, flag_warm_start, flag_ls,  mub, prec, Ng);
     elseif strcmp(algo,'CMP')
        flag_warm_start = 1;
        flag_ls         = 1;
        mub             = 20000;
        prec            = 10^(-6);
        Ng              = 20;
        [Matbeta, ~, ~, ~, ITC] = cmp( y, X, flag_warm_start, flag_ls,  mub, prec, Ng);
    else
        fprintf('Incorrect greedy algorithm');
        return;
    end
    [~,cvstep] = CV(y, X, algo);    
    
    %Testing
    y_new = yy(start+n:start+n+nstep-1);
    X_new = [];
    for c=1:size(XX,2)
        X_new = [X_new toeplitz(XX(start+n-1:start+n+nstep-2,c),XX(start+n-1:-1:start,c)')];
    end
    for jj=1:size(X_new,2)
        X_new(:,jj) = X_new(:,jj) - mean( X(:,jj) );
        noj = norm(X(:,jj));
        if noj>0
            X_new(:,jj) = sqrt(n)*( X_new(:,jj)/noj );
        end
    end
    
    meany_new   = mean(y);
    
    %ITC
    for ind = 1: size(ITC,1)
        [~,w] = min(ITC(ind,:));
        betahat = Matbeta(:,w);
        ERRORS(flag_others+1,ind,:,start-n) = y_new - (X_new*betahat + meany_new);        

    end %for
    
    %cv
    cvbetahat = Matbeta(:,cvstep);
    ERRORS(flag_others+1,size(ITC,1)+1,:,start-n) = y_new - (X_new*cvbetahat + meany_new); 
    
   
    start = start+1;
    
end %while

save(fname,'ERRORS');


end %main

