function [mat_res, mat_score_itc, mat1, mat2] = read_results_17dec_2021(n)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input:
% n                 = sample size
% Output:
% mat_res           = values MISE 
%                   rows: 
%                   row1          = vec_algo{1}/OMP_itc{1}
%                   row2          = vec_algo{1}/OMP_itc{2}
%                   last row      = vec_algo{3}/CMP_itc{12}
%                   each col. corresponds to a "condition"
% mat_score_itc     = scores aggregated for 3 algorithms
%                   each row corresponds to an ITC
%                   each col. corresponds to a "condition"
% mat1              = normalized scores written in the table 
% mat2              = acronyms ITC written in the table 
%                   Table is saved automatically
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

vec_algo = {'OMP', 'FWA', 'CMP'};

OMP_itc = {'AIC$_C$', 'KIC', 'KIC$_C$', 'BIC', 'EBIC', 'EBIC$^\circ$', 'SC', 'ESC', ...
    'gMDL', 'EgMDL', 'MMLU', 'MMLG'};
FWA_itc = OMP_itc;
CMP_itc = OMP_itc;

pos           = zeros(length(vec_algo)+1,1);
pos(1)        = 1;
pos(2)        = pos(1) + length(OMP_itc);
pos(3)        = pos(2) + length(FWA_itc);
pos(4)        = pos(3) + length(CMP_itc);

k = 0;
for ind_algo=1:length(vec_algo)
    algo = char( vec_algo{1,ind_algo} );
    eval(['vec_itc =' strcat(algo,'_itc;') ]);
    for ind_itc=1:length(vec_itc)
        k = k+1;
        itc = char( vec_itc{1,ind_itc} );
        vec_met{k} = strcat(algo,'_',itc);
    end
end

vec_om      = [0 0.75];                  
vec_sigma   = [sqrt(8) sqrt(0.2)];    %controls SNR 
mat_res     = Inf(length(OMP_itc)+length(FWA_itc)+length(CMP_itc), ...
                    4*3*length(vec_om)*length(vec_sigma)); %4 Models, 3 Cases

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
% Models and Cases are the same as in Sancetta (2016)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Models (definitions as in Sancetta 2016):
% model 1:   low-dimensional model
% model 2:   high-dimensional small equal coefficients
% model 3:   high-dimensional decaying coefficients
% model 4:   high-dimensional slowly decaying coefficients
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


for ind_algo = 1:length(vec_algo)
    algo = char( vec_algo{1,ind_algo} );
    %Folder results
    folder_name = strcat('./Results_n_', ...
        num2str(n), ...
        '_', ...
        algo);
    
    ind_mat_res   = 0;
    
    for model = 1:4 %all Models
        extra = strcat('Model_',num2str(model));
        folder_name2 = strcat(folder_name,'/',extra);
        
        for Case=1:3 %all Cases
            extra2 = strcat('Case_',num2str(Case));
            folder_name3 = strcat(folder_name2,'/',extra2);
            
            fname_MISE = strcat(folder_name3, ...
            '/MISE', ...
            '.mat');
            eval(['load ', fname_MISE]);
            
             for ind_om = 1:length(vec_om)
                 
                 for ind_sig=1:length(vec_sigma)
                     
                     ind_mat_res = ind_mat_res+1;
                     mat_res( pos(ind_algo):pos(ind_algo+1)-1, ind_mat_res ) ...
                         = squeeze( MISE(ind_om,ind_sig,:) );
                    
                 end %ind_sig
             end %ind_om
        end %Case
    end %model
end %algo


mat_score_itc = zeros(size(mat_res,1)/length(vec_algo), size(mat_res,2));
for ind_algo = 1:length(vec_algo)
    mat_score_itc = res2score(mat_res(pos(ind_algo):pos(ind_algo+1)-1,:), mat_score_itc);
end

C = cell(12,1); %No. of ITC = 12
%Cols in mat_score_itc for various "conditions"
%Model1
C{1,1} = (1:12);
%Model2
C{2,1} = C{1,1}+12;
%Model3
C{3,1} = C{1,1}+(2*12);
%Model4
C{4,1} = C{1,1}+(3*12);
%Case1
C{5,1} = [1:4 13:16 25:28 37:40];
%Case2
C{6,1} = C{5,1} + 4;
%Case3
C{7,1} = C{5,1} + (2*4);
%Omega 0
C{8,1} = union( (1:4:48),(2:4:48) );
%Omega 0.75
C{9,1} = union( (3:4:48),(4:4:48) );
%High SNR
C{10,1} = (1:2:48);
%Low SNR
C{11,1} = (2:2:48);
%Total
C{12,1} = (1:48);


mat1 = Inf(12,12);      %matrix normalized scores
mat2 = cell(12,12);     %matrix names ITC
for index = 1:12
   [mat1,mat2] = build_mat(mat_score_itc, C{index,1}, OMP_itc, index, mat1, mat2); 
end

build_table(mat1,mat2,n);

end %function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function mat_score_itc = res2score(mat_res, mat_score_itc)

mat_score = Inf(size(mat_score_itc));

for j=1:size(mat_score,2)
    
    [mi,~] = min(mat_res(:,j));
    mm = mi + (5/100)*mi;
    
    for i=1:size(mat_score,1)
        if mat_res(i,j)==mi
            mat_score(i,j) = 1;
        elseif mat_res(i,j)<=mm
            mat_score(i,j) = 0.5;
        else
            mat_score(i,j) = 0;
        end
    end %i
end %j

mat_score_itc = mat_score_itc + mat_score;

end %function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [mat1,mat2] = build_mat(mat_score_itc, cols, OMP_itc, index, mat1, mat2)

total = sum(mat_score_itc(:,cols),2);
total = total./(3*length(cols)); %the scores for 3 algorithms were aggregated
[ts, inds] = sort(total,'descend');
mat1(:,index) = ts;
mat2(:,index) = OMP_itc(inds)';

end %function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function build_table(mat1,mat2,n)

name = {'Model 1', 'Model 2', 'Model 3', 'Model 4', 'Case 1', 'Case 2', 'Case 3', '$\omega=0$', ...
    '$\omega=0.75$', 'High SNR', 'Low SNR', 'Total'};

fname = './';
fname = strcat(fname, 'table_', num2str(n), '.tex');
fid = fopen(fname,'w+');

fprintf(fid,'%s \n','\begin{table}');
fprintf(fid,'%s \n','\centering');
fprintf(fid,'%s \n','\scalebox{0.8}{\begin{tabular}[t!]{llllllllllll}');
fprintf(fid,'%s \n','\hline \\');
for i=1:(length(name)/2-1)
    fprintf(fid, '%s %s', char(name(i)), '& ');
end
i = length(name)/2;
fprintf(fid, '%s %s', char(name(i)), '\\');
fprintf(fid,'%s \n','\hline \\');

for i=1:size(mat1,1)
    for j=1:(size(mat1,2)/2-1)
        fprintf(fid, '%s (%3.2f) %s', char(mat2(i,j)), mat1(i,j), '& '); 
    end
    j = size(mat1,2)/2;
    fprintf(fid, '%s (%3.2f) %s \n', char(mat2(i,j)), mat1(i,j), '\\'); 
end

fprintf(fid,'%s \n','\hline \\');
for i=(length(name)/2+1):(length(name)-1)
    fprintf(fid, '%s %s', char(name(i)), '& ');
end
i = length(name);
fprintf(fid, '%s %s', char(name(i)), '\\');
fprintf(fid,'%s \n','\hline \\');

for i=1:size(mat1,1)
    for j=(size(mat1,2)/2+1):(size(mat1,2)-1)
        fprintf(fid, '%s (%3.2f) %s', char(mat2(i,j)), mat1(i,j), '& '); 
    end
    j = size(mat1,2);
    fprintf(fid, '%s (%3.2f) %s \n', char(mat2(i,j)), mat1(i,j), '\\'); 
end

fprintf(fid,'%s \n','\hline');
fprintf(fid,'%s \n','\end{tabular}}');
fprintf(fid,'%s \n','\end{table}');

fclose(fid);

end% function 



	
