function MISE = comp_MISE(MISE, Case, ind_om, vec_om, ind_sig, betatrue, Matbeta, ITC, n, p)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input:
% MISE          = MISE computed at the previous stage 
%                 MISE size: 2 * 2 * no. of ITC
% Case          = Case
% ind_om        = index omega
% vec_om        = vector values omega
% ind_sig       = index variance (SNR)
% betatrue      = vector beta true linear coefficients (p * 1)
% Matbeta       = matrix of est. beta vectors  
%                 Matbeta size: p * no. of iterations
% ITC           = no. of rows = no. of ITC 
%                 no. of cols = no. of iterations
% n             = sample size training
% p             = no. of linear param.
% Output:
% MISE          = MISE computed at the current stage 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

omega0          = vec_om(ind_om);

%Generate X for prediction               
[theta, T]  = get_T_theta(Case,n);
X_out       = genX(10*n,p,T,theta,omega0);

%Transform  data
for jj = 1:p
    X_out(:,jj) = X_out(:,jj) - mean(X_out(:, jj));
    X_out(:,jj) = sqrt(10*n)*( X_out(:,jj)/norm(X_out(:,jj)) );
end

%Compute MISE
for ind=1:size(ITC,1)
    [~,w] = min(ITC(ind,:));
    betahat = Matbeta(:,w);
    err_out = X_out*betatrue - X_out*betahat;
    MISE(ind_om,ind_sig,ind) = MISE(ind_om,ind_sig,ind) + mean(err_out.^2 );
end %ind

end %function


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [theta, T] = get_T_theta(Case,n)

if Case == 1
    T       = 0;
    theta   = 1;
elseif Case == 2
    T       =  100 + n;
    theta   =  0.95.^(0:T); 
elseif Case == 3
    T       =  1000 + n;
    theta   = (1:T+1).^(-1/2); 
else
end

end %function

