function run_exp_sance_dec14_2021(n, algo)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input:
% n     = sample size
% algo  = greedy algorithm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
NTR = 100;                          %no. of trials
% NTR = 20;                          %no. of trials

p = 100;                          %total no. of predictors
vec_om = [0 0.75];                  %
vec_sigma = [sqrt(8) sqrt(0.2)];    %controls SNR 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Models (definitions as in Sancetta 2016):
% model 1:   low-dimensional model
% model 2:   high-dimensional small equal coefficients
% model 3:   high-dimensional decaying coefficients
% model 4:   high-dimensional slowly decaying coefficients
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Cases are the same as in Sancetta 2016

%Create folders for saving the results
folder_name = strcat('./SimulationResults/Results_n_', ...
    num2str(n), ...
    '_', ...
    algo);
[suc,~,~] = mkdir(folder_name);
if suc==0
    return;
end
for model = 1:4 %all Models
    extra = strcat('Model_',num2str(model));
    [suc,~,~] = mkdir(folder_name,extra);
    if suc==0
        return;
    end
    folder_name2 = strcat(folder_name,'/',extra);
    for Case=1:3 %all Cases
        extra2 = strcat('Case_',num2str(Case));
        [suc,~,~] = mkdir(folder_name2,extra2);
        if suc==0
            return;
        end
    end
end



%Main loop
for model = 1:4 %all Models
    % fprintf('Model %i:\n', model);
    
    for Case=1:3 %all cases
        % fprintf('Case %i:\n', Case);
        if sum(strcmp(algo,{'MPA','RMP'}))==1
            MISE = zeros(2,2,22);
        elseif sum(strcmp(algo,{'OMP','FWA','CMP'}))==1
            MISE = zeros(2,2,12);
        else
            fprintf('ERROR\n');
            return;
        end
        
        for ind_om = 1:length(vec_om)
            % fprintf('omega %3.2f:\n', vec_om(ind_om));
            omega = vec_om(ind_om);
            
            for tr=1:NTR
%                 fprintf('.');
%                 if rem(tr,25)==0
%                     fprintf('\n');
%                 end
                
                %Generate data
                [X, Maty, betatrue, ~] = gendata(n,model,Case,p,vec_sigma,omega);
                
                for ind_sig=1:length(vec_sigma)
                    y = Maty(:,ind_sig);
                    
                    %Training
                    [Matbeta, ITC] = train(y, X, algo);
                    
                    %Testing: Compute MISE
                    MISE = comp_MISE(MISE, Case, ind_om, vec_om, ind_sig, betatrue, Matbeta, ITC, n, p);
                    
                end %ind_sig
                
            end %tr
            
        end %ind_om
        
        MISE = MISE./(NTR*10*n);
        
        fname_MISE = strcat(folder_name, ...
            '/Model_',num2str(model), ...
            '/Case_',num2str(Case), ...
            '/MISE', ...
            '.mat');
        save(fname_MISE, 'MISE');
        
    end % Case
    
    
end % Model

end %function