function draw_fpr(Th)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% Th = threshold 0.5:0.1:0.9
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ALGO        = {'OMP', 'FWA', 'CMP'};             %algorithms
ITC_lab     =  {'AIC$_C$', 'KIC', 'KIC$_C$', 'BIC', 'EBIC', 'EBIC$^\circ$', 'SC', 'ESC', ...
    'gMDL', 'EgMDL', 'MMLU', 'MMLG'};
vec_ct      = [1 1/10 1/100];                    %vector values ct
vec_len     = [50 100 200];                      %vector length blocks
vec_Th      = (0.5:0.1:0.9);                     %vector thresholds


ind_Th = find(vec_Th==Th);
if numel(ind_Th)==0
    fprintf('Incorrect value Th\n');
    return;
end

for ind_algo=1:length(ALGO)
    draw_fpr_algo(ind_Th, ind_algo, vec_Th, ALGO, vec_len, ITC_lab, vec_ct);
end

end %function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function draw_fpr_algo(ind_Th, ind_algo, vec_Th, ALGO, vec_len, ITC_lab, vec_ct)

col = [
    0 0.4470 0.7410
    0.8500 0.3250 0.0980
    0.4940 0.1840 0.5560
    1 0 1 %0.4660 0.6740 0.1880
    0 0.5 0 %0.3010 0.7450 0.9330
    0.6350 0.0780 0.1840
    0 0 1
    1 0 0
    0 0.75 0.75
    0.75 0 0.75
    0.75 0.75 0
    0.25, 0.25, 0.25
    ];

load('All_results50.mat');

FigH=figure(ind_algo);
set(gcf, 'Position', get(0, 'Screensize'));

for ii=1:3
    x = squeeze( FP(:,:,ind_algo,ii,ind_Th,:) );
    xx = squeeze(mean(x,1));
      
    subplot(3,1,ii);
    bb=bar(xx);
    
    if ii==1
        tit = sprintf('%s %s %s %2.1f%s', ...
            'FPR for the greedy algorithm', char(ALGO(ind_algo)), 'when \psi=', (vec_Th(ind_Th)*100), '%');
    else
        tit = [];
    end
    yl = sprintf('%s %s', 'Block length =', num2str(vec_len(ii)));
    title({tit; ' '; ' '; ' '});
    ylabel(yl);
    if ii==3
        xlabel('\phi');
    end
    
    %Colors
    for j=1:12
        eval(['bb(' num2str(j) ').FaceColor = col(' num2str(j) ',:);' ])
    end
    
    %Text
    hAx=gca;            % get a variable for the current axes handle
    hAx.XTickLabel=vec_ct; % label the ticks
    hT=[];              % placeholder for text object handles
    for i=1:length(bb)  % iterate over number of bar objects
        hT=[hT text(bb(i).XData+bb(i).XOffset,bb(i).YData, ...
            ITC_lab(:,i), ...
            'VerticalAlignment','baseline','horizontalalign','left', ...
            'rotation',90)];
    end
    h = findobj(gca, 'type', 'text');
    set(h,'FontSize',8);
    set(h,'Interpreter','latex');
    
end

cc = num2str(vec_Th(ind_Th));
cc = cc([1 end]);
fname = strcat('FPR_', char(ALGO(ind_algo)), '_Th_', cc, '.eps');
% print(FigH','-depsc2','-painters',fname);
saveas(FigH, fname ,'epsc2');

end %function

