function draw_tpr(Th)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% Th = threshold 0.5:0.1:0.9
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ALGO        = {'OMP', 'FWA', 'CMP'};             %algorithms
ITC_lab     =  {'AIC$_C$', 'KIC', 'KIC$_C$', 'BIC', 'EBIC', 'EBIC$^\circ$', 'SC', 'ESC', ...
    'gMDL', 'EgMDL', 'MMLU', 'MMLG'};
% vec_ct      = [1 1/10 1/100];                    %vector values ct
vec_len     = [50 100 200];                      %vector length blocks
vec_Th      = (0.5:0.1:0.9);                     %vector thresholds


ind_Th = find(vec_Th==Th);
if numel(ind_Th)==0
    fprintf('Incorrect value Th\n');
    return;
end

for ind_algo=1:length(ALGO)
    draw_tpr_algo(ind_Th, ind_algo, vec_Th, ALGO, vec_len, ITC_lab);
end

end %function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function draw_tpr_algo(ind_Th, ind_algo, vec_Th, ALGO, vec_len, ITC_lab)

load('All_results50.mat');

FigH=figure(ind_algo);
set(gcf, 'Position', get(0, 'Screensize'));

for i=1:3
    
    x = [squeeze( TP(:,1,ind_algo,i,ind_Th,:) ) squeeze( TP(:,2,ind_algo,i,ind_Th,:) ) squeeze( TP(:,3,ind_algo,i,ind_Th,:) ) ];
    
    if i==1
        tit = sprintf('%s %s %s %2.1f%s', ...
            'TPR for the greedy algorithm', char(ALGO(ind_algo)), 'when \psi=', (vec_Th(ind_Th)*100), '%');
    else
        tit = [];
    end
    yl = sprintf('%s %s', 'Block length =', num2str(vec_len(i)));
    
    subplot(3,1,i);
    mod_boxplot(x, tit, yl, ind_algo, ITC_lab, i);
    
end

cc = num2str(vec_Th(ind_Th));
cc = cc([1 end]);
fname = strcat('TPR_', char(ALGO(ind_algo)), '_Th_', cc, '.eps');
% print(FigH','-depsc2','-painters',fname);
saveas(FigH, fname ,'epsc2');

end %function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function mod_boxplot(results, tit, yl, fig_no, ITC_lab, sb)

figure(fig_no);
Label_size = 10;

% make some grouping labels
g1 = repmat([1 1 1 1 1 1 1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 2 2 3 3 3 3 3 3 3 3 3 3 3 3],size(results,1),1);
g2 = repmat('abcdefghijklabcdefghijklabcdefghijkl',size(results,1),1);

% reshape everything into columns
zv = results(:);
gp1 = g1(:);
gp2 = g2(:);

col = [
    0 0.4470 0.7410
    0.8500 0.3250 0.0980
    0.4940 0.1840 0.5560
    1 0 1 %0.4660 0.6740 0.1880
    0 0.5 0 %0.3010 0.7450 0.9330
    0.6350 0.0780 0.1840
    0 0 1
    1 0 0
    0 0.75 0.75
    0.75 0 0.75
    0.75 0.75 0
    0.25, 0.25, 0.25
    ];

if sb<3
    lab     =  {' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ...
        ' ', ' ', ' ', ' '};
else
    lab = ITC_lab;
end

boxplot(zv,{gp1,gp2},'factorgap',[20 2], 'FactorSeparator',[1 1], ...
    'label', repmat(lab,1,3), ...
    'LabelOrientation', 'inline', ...
    'symbol','g+', ...
    'colors', col);
%ylim([min(zv) max(zv)]);


ylabel(yl,'FontSize',Label_size);
title(tit,'FontSize',Label_size);
h = findobj(gca, 'type', 'text');

set(gca,'FontSize',Label_size);
set(gca,'TickLength',[0 0]);
% set(findobj(gca,'type','line'),'linew',2);
% set(gca,'LineWidth',2);
set(h,'FontSize',Label_size);
set(h,'Interpreter','latex');
if sb~=1
    pos=get(gca,'Position');
    pos1=pos+[0 .05*(sb-1) 0 0];
    set(gca,'Position',pos1);
end
if sb==3
    pos = get(h,'Position');
    pos = cellfun(@(y) [y(1) y(2)+25 y(3)],pos,'un',0);
    set(h, {'Position'}, pos);
end

end %function
