function [Y, X0, beta_true, spec_rad, pmax, s] = gendata(ct, init)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% ct   = std. for errors is ct*cs
% init = no. of samples initialization
%Output:
% Y             = matrix measurements (T X K)
% X0            = matrix ex. var. (T X s)
% beta_true     = vector true values all pred. (100 X 1)
% spec_rad      = spectral radius VAR
% pmax          = max. VAR order used in estimation
% s             = total number ex. predictors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
K                                   = 4;                        %no. time series
p                                   = 3;                        %true VAR order
pmax                                = 4;                        %max VAR order
c                                   = zeros(K,1);               %intercept
pz                                  = 0.6;                      %max prob. of zero entries VAR coeff.
cs                                  = 0.25;                     %std of matrix coefficients
[Atrue, ~, spec_rad]                = gen_coeff(K, p, cs, pz);  %VAR coeff.
s                                   = 100 - pmax*K;             %number ex. predictors
Beta                                = zeros(K,s);
beta                                = [ones(1,3) zeros(1,s-3)]; %coeff. ex. predictors
Beta(1,:)                           = beta;
Sigma                               = (cs*ct)*eye(K);
Mdl                                 = varm('Constant', c, ...
                                        'AR', Atrue, ...
                                        'Beta', Beta, ...
                                        'Covariance', Sigma);
T                           = 2*10^4+init;                      %total no. of samples
X0                          = cs*randn(T+init,s);               %ex. predictors
X0(:,1)                     = gen_ar1([1 0.9], X0(:,1));        %AR(1)
X0(:,2)                     = gen_ar1([1 0.5], X0(:,2));        %AR(1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[Y,~]                       = simulate(Mdl,T+init,'X',X0);      %generate data
Y                           = Y(init+1:end,:);                  %discard init. values
X0                          = X0(init+1:end,:);                 %discard init. values ex. pred.
At                          = cell2mat(Atrue);                      
beta_true                   = [At(1,:)'                         %true values all pred. 
                                zeros(1,(pmax-p)*K)'
                                beta'];

end %function                            
                            
                            



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function y = gen_ar1(arcoeff, x)

y = filter(1, arcoeff, x);
y = y.*sqrt(1-arcoeff(2)^2);

end %function
            
