function [TotalSelP, count] = run_algo(Y, X0, algo, init, len, distb, pmax, s, NoITC)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% Y             = matrix measurements (T X K)
% X0            = matrix ex. var. (T X s)
% algo          = greedy algorithm
% init          = no. samples initialization
% len           = length block
% distb         = dist. between consecutive blocks
% pmax          = max. VAR order used in estimation
% s             = total number ex. predictors
% NoITC         = total no. ITC
%Output:
% TotalSelP     = Matrix 100 X NoITC; entry=1 when pred. sel., 0 otherwise 
% count         = total number of blocks 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[T, K]      = size(Y);
TotalSelP   = zeros(K*pmax+s,NoITC); %tot. no. pred. X tot. no. ITC

count = 0;

for pos=init+1:len+distb:T
    count=count+1;

    %Construct y and X
    y = Y(pos:pos+len-1,1);
    X = [];
    for ii=1:pmax
        for jj=1:K
            X = [X Y(pos-ii:pos-ii+len-1,jj)];
        end
    end
    X = [X X0(pos:pos+len-1,:)];
    
    %Run algorithm
    [Matbeta, ITC] = train(y, X, algo);
    for i=1:size(ITC,1)
        [~,it] = min(ITC(i,:));
        TotalSelP(:,i) = TotalSelP(:,i) + (Matbeta(:,it)~=0);
    end %i 
end %pos

end %function



 

